from flask import Flask, render_template
from typing import List

app = Flask(__name__)


class Consumable:
    def __init__(self, name: str, date: str, kind: str):
        self.name = name
        self.expiry_date = date
        self.expired = False
        self.kind = kind

    def check_expired(self, current_date: str):
        date1 = self.expiry_date.split('.')
        date2 = current_date.split('.')
        if int(date2[2]) > int(date1[2]):
            self.expired = True
        elif int(date2[1]) > int(date1[1]) and int(date1[2]) == int(date1[2]):
            self.expired = True
        elif int(date2[0]) > int(date1[0]) and int(date1[2]) == int(date1[2]) and int(date1[1]) == int(date1[1]):
            self.expired = True


class Refrigerator:
    def __init__(self, consumables: List[Consumable]):
        self.consumables = consumables


@app.route("/consumables")
def content():
    return render_template("content.html")


@app.route("/consumables/vegetables/<string:date>")
def show_vegetables(date):
    veggies = [element for element in fridge1.consumables if element.kind == "Gemuese"]

    for index in range(len(veggies)):
        veggies[index].check_expired(date)

    return render_template("kind.html", liste=veggies)


@app.route("/consumables/fruits/<string:date>")
def show_fruits(date):
    fruechte = [element for element in fridge1.consumables if element.kind == "Frucht"]

    for index in range(len(fruechte)):
        fruechte[index].check_expired(date)

    return render_template("kind.html", liste=fruechte)


@app.route("/consumables/meat/<string:date>")
def show_meat(date):
    meats = [element for element in fridge1.consumables if element.kind == "Fleisch"]

    for index in range(len(meats)):
        meats[index].check_expired(date)

    return render_template("kind.html", liste=meats)


fridge1 = Refrigerator([
    Consumable('Fisch', '31.12.2019', "Fleisch"),
    Consumable('Drachenfrucht', '29.02.2020', "Frucht"),
    Consumable('Dosenfleich', '54. 65. 12019', "Fleisch"),
    Consumable('Blumenkohl', '15.10.2017', "Gemuese"),
    Consumable('Apfel', '25.01.2000', "Frucht"),
    Consumable('Karotte', '20.11.2019', "Gemuese"),
    Consumable('Schweinefleisch', '01.01.1900', "Fleisch"),
    Consumable('Spinat', '31.10.2026', "Gemuese"),
    Consumable('Banane', '03.05.2019', "Frucht"),
    Consumable('Mangold', '01.07.2020', "Gemuese"),
    Consumable('Rindfleisch', '15.10.1955', "Fleisch"),
    Consumable('Kiwi', '03.03.2020', "Frucht")
])

if __name__ == '__main__':
    app.debug = True
    app.run()
